# Quality-Toolkit

Toolkit for the quality in order to help writing tests

## Contribution

Clone the project

```bash
git clone https://github.com/veepee-oss/quality-toolkit quality-toolkit
cd quality-toolkit
```

## Installation in local

```bash
make install
```

## Installation in a project

Edit the project's requirements.txt and add the line :

```txt
quality-toolkit
```

and finish by install the project dependencies :

```bash
pip3 install
```

## How to use the lib

See the list of available componants :

* [Helpers](docs/helpers.md)
* [Services](docs/services.md)
